@@ -10,7 +10,8 @@
 #ifndef RENDERINGCDISPLAYRENDERING_H
 #define RENDERINGCDISPLAYRENDERING_H
 
-#include "chtmlexportrendering.h"
+#include "backend/rendering/chtmlexportrendering.h"
+
 
 namespace Rendering {
 
@@ -20,17 +21,17 @@ namespace Rendering {
  */
 
 class CDisplayRendering : public CHTMLExportRendering {
-public:
-	static const QString keyToHTMLAnchor(const QString& key);
+    public:
+        static const QString keyToHTMLAnchor(const QString& key);
 
-	CDisplayRendering(
-		CSwordBackend::DisplayOptions displayOptions = CBTConfig::getDisplayOptionDefaults(),
-		CSwordBackend::FilterOptions filterOptions = CBTConfig::getFilterOptionDefaults()
-	);
+        CDisplayRendering(
+            CSwordBackend::DisplayOptions displayOptions = CBTConfig::getDisplayOptionDefaults(),
+            CSwordBackend::FilterOptions filterOptions = CBTConfig::getFilterOptionDefaults()
+        );
 
-protected:
-	virtual const QString entryLink( const KeyTreeItem& item, CSwordModuleInfo* const module );
-	virtual const QString finishText( const QString&, KeyTree& tree );
+    protected:
+        virtual const QString entryLink( const KeyTreeItem& item, CSwordModuleInfo* const module );
+        virtual const QString finishText( const QString&, KeyTree& tree );
 };
 
 }
