@@ -10,18 +10,14 @@
 #ifndef CENTRYDISPLAY_H
 #define CENTRYDISPLAY_H
 
-//BibleTime
-//#include "ctextrendering.h"
-class CSwordModuleInfo;
-#include "backend/managers/cswordbackend.h"
-
 #include "util/cpointers.h"
 
-//Sword
+#include <QString>
+#include "backend/managers/cswordbackend.h"
+
+// Sword includes:
 #include <swdisp.h>
 
-//Qt
-#include <QString>
 
 class CSwordModuleInfo;
 
@@ -35,14 +31,14 @@ namespace Rendering {
 
 class CEntryDisplay : public sword::SWDisplay, public CPointers {
 
-public:
-	virtual ~CEntryDisplay() {}
+    public:
+        virtual ~CEntryDisplay() {}
 
-	/**
-	* Returns the rendered text using the modules in the list and using the key parameter.
-	* The displayoptions and filter options are used, too.
-	*/
-	virtual const QString text( const QList<CSwordModuleInfo*>& modules, const QString& key, const CSwordBackend::DisplayOptions displayOptions, const CSwordBackend::FilterOptions filterOptions);
+        /**
+        * Returns the rendered text using the modules in the list and using the key parameter.
+        * The displayoptions and filter options are used, too.
+        */
+        virtual const QString text( const QList<CSwordModuleInfo*>& modules, const QString& key, const CSwordBackend::DisplayOptions displayOptions, const CSwordBackend::FilterOptions filterOptions);
 };
 
 
