@@ -10,20 +10,19 @@
 #ifndef BIBLETIMEAPP_H
 #define BIBLETIMEAPP_H
 
-//BibleTime
+#include <QApplication>
 #include "util/cpointers.h"
 
-#include <QApplication>
 
 /** The BibleTimeApp class is used to clean up all instances of the backend and to delete all created module objects.
   * @author The BibleTime team
   */
 class BibleTimeApp : public QApplication, public CPointers {
-public:
-	BibleTimeApp( int & argc, char ** argv );
-	virtual ~BibleTimeApp();
+    public:
+        BibleTimeApp(int &argc, char **argv);
+        ~BibleTimeApp();
 
-protected:
+    protected:
 //	void initDCOP();
 };
 
