@@ -12,19 +12,19 @@
 
 #include <QDialog>
 
+
 class CSwordModuleInfo;
 class QWidget;
 
 /**
-	Dialog to show the information about a module.
-	
-	@author The BibleTime team <info@bibletime.info>
+    Dialog to show the information about a module.
+
+    @author The BibleTime team <info@bibletime.info>
 */
-class BTAboutModuleDialog : public QDialog
-{
-	Q_OBJECT
-public:
-    BTAboutModuleDialog(QWidget* parent, CSwordModuleInfo* info);
+class BTAboutModuleDialog : public QDialog {
+        Q_OBJECT
+    public:
+        BTAboutModuleDialog(QWidget* parent, CSwordModuleInfo* info);
 };
 
 #endif
