@@ -7,35 +7,33 @@
 *
 **********/
 
-#include "btbookmarkitembase.h"
-#include "cbookmarkindex.h"
+#include "frontend/mainindex/bookmarks/btbookmarkitembase.h"
 
-#include <QTreeWidgetItem>
 #include <QDropEvent>
+#include <QTreeWidgetItem>
+#include "frontend/mainindex/bookmarks/cbookmarkindex.h"
 
-BtBookmarkItemBase::BtBookmarkItemBase()
-{}
+
+BtBookmarkItemBase::BtBookmarkItemBase() {}
 
 BtBookmarkItemBase::BtBookmarkItemBase(QTreeWidgetItem* parent)
-	: QTreeWidgetItem(parent)
-{}
+        : QTreeWidgetItem(parent) {}
 
-CBookmarkIndex* BtBookmarkItemBase::bookmarkWidget() const
-{
-	return dynamic_cast<CBookmarkIndex*>(treeWidget());
+CBookmarkIndex* BtBookmarkItemBase::bookmarkWidget() const {
+    return dynamic_cast<CBookmarkIndex*>(treeWidget());
 }
 
 // void BtBookmarkItemBase::dropped(QDropEvent* e)
 // {
-// 
+//
 // }
-// 
+//
 // void BtBookmarkItemBase::addPreviousSibling(BtBookmarkItemBase* item)
 // {
-// 
+//
 // }
-// 
+//
 // void BtBookmarkItemBase::addNextSibling(BtBookmarkItemBase* item)
 // {
-// 
+//
 // }
