@@ -10,12 +10,12 @@
 #ifndef SEARCHCSEARCHANALYSISDIALOG_H
 #define SEARCHCSEARCHANALYSISDIALOG_H
 
+#include <QDialog>
+
+#include <QObject>
+
 
 class CSwordModuleInfo;
-
-#include <QDialog>
-#include <QObject>
-				 
 class QAbstractButton;
 class QDialogButtonBox;
 
@@ -24,33 +24,29 @@ namespace Search {
 class CSearchAnalysisView;
 class CSearchAnalysisScene;
 
-
-
 /**
 	@author The BibleTime team <info@bibletime.info>
 */
-class CSearchAnalysisDialog : public QDialog
-{
-	Q_OBJECT
+class CSearchAnalysisDialog : public QDialog {
+        Q_OBJECT
+    public:
+        CSearchAnalysisDialog(QList<CSwordModuleInfo*> modules, QWidget* parentDialog);
+        ~CSearchAnalysisDialog() {}
 
-public:
-	CSearchAnalysisDialog(QList<CSwordModuleInfo*> modules, QWidget* parentDialog);
-	~CSearchAnalysisDialog() {}
+    protected: // Protected methods
+        /**
+         * Initializes this dialog.
+         */
+        void initView();
+        void resizeEvent(QResizeEvent* event);
 
-protected: // Protected methods
-	/**
-	 * Initializes this dialog.
-	 */
-	void initView();
-	void resizeEvent(QResizeEvent* event);
-	
-private slots:
-	void buttonClicked(QAbstractButton* button);
-	
-private:
-	CSearchAnalysisScene* m_analysis;
-	CSearchAnalysisView* m_analysisView;
-	QDialogButtonBox* m_buttonBox;
+    private slots:
+        void buttonClicked(QAbstractButton* button);
+
+    private:
+        CSearchAnalysisScene* m_analysis;
+        CSearchAnalysisView* m_analysisView;
+        QDialogButtonBox* m_buttonBox;
 };
 
 }
