@@ -10,23 +10,23 @@
 #ifndef SEARCHCSEARCHANALYSISLEGENDITEM_H
 #define SEARCHCSEARCHANALYSISLEGENDITEM_H
 
-class CSwordModuleInfo;
-
 #include <QGraphicsRectItem>
 
+
+class CSwordModuleInfo;
+
 namespace Search {
 
 /**
-	@author The BibleTime team <info@bibletime.info>
+    @author The BibleTime team <info@bibletime.info>
 */
-class CSearchAnalysisLegendItem : public QGraphicsRectItem
-{
-public:
-	CSearchAnalysisLegendItem(QList<CSwordModuleInfo*>* list );
+class CSearchAnalysisLegendItem : public QGraphicsRectItem {
+    public:
+        CSearchAnalysisLegendItem(QList<CSwordModuleInfo*>* list );
 
-private:
-	virtual void paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget*);
-	QList<CSwordModuleInfo*>* m_moduleList;
+    private:
+        virtual void paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget*);
+        QList<CSwordModuleInfo*>* m_moduleList;
 
 };
 
