@@ -7,34 +7,33 @@
 *
 **********/
 
-#include "csearchanalysisview.h"
-#include "csearchanalysisscene.h"
+#include "frontend/searchdialog/analysis/csearchanalysisview.h"
 
-#include <QWidget>
 #include <QGraphicsView>
 #include <QResizeEvent>
+#include <QWidget>
+#include "frontend/searchdialog/analysis/csearchanalysisscene.h"
 
 
 namespace Search {
 
 CSearchAnalysisView::CSearchAnalysisView(CSearchAnalysisScene* scene, QWidget* parent)
- : QGraphicsView(scene, parent)
-{
-	setFocusPolicy(Qt::WheelFocus);
-	setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-	resize(sizeHint());
+        : QGraphicsView(scene, parent) {
+    setFocusPolicy(Qt::WheelFocus);
+    setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    resize(sizeHint());
 }
 
 
 /** Returns the sizeHint for this view */
 QSize CSearchAnalysisView::sizeHint() const {
-	return QGraphicsView::sizeHint();
+    return QGraphicsView::sizeHint();
 }
 
 /** No descriptions */
 void CSearchAnalysisView::resizeEvent( QResizeEvent* e) {
-	QGraphicsView::resizeEvent(e);
-	scene()->setSceneRect(0,0, scene()->sceneRect().width(), viewport()->height() );
+    QGraphicsView::resizeEvent(e);
+    scene()->setSceneRect(0, 0, scene()->sceneRect().width(), viewport()->height() );
 }
 
 
