@@ -11,9 +11,9 @@
 
 #include <QtTest/QtTest>
 
-void BibleTimeTest::dummyTest() 
-{ 
-	QCOMPARE(QString("Hello").toUpper(), QString("HELLO")); 
+
+void BibleTimeTest::dummyTest() {
+    QCOMPARE(QString("Hello").toUpper(), QString("HELLO"));
 }
 
 
