@@ -12,16 +12,16 @@
 
 #include <QObject>
 
-class BibleTimeTest: public QObject
-{
-	Q_OBJECT
 
-private slots:
-	//frontend
-    void frontend_cbtconfig_test();
-    
-    //dummy test
-    void dummyTest();
+class BibleTimeTest: public QObject {
+        Q_OBJECT
+
+    private slots:
+        //frontend
+        void frontend_cbtconfig_test();
+
+        //dummy test
+        void dummyTest();
 };
 
 
